//
//  Test_3x3mulM.h
//  BulletTest
//
//  Copyright (c) 2011 Apple Inc.
//

#ifndef BulletTest_Test_3x3mulM_h
#define BulletTest_Test_3x3mulM_h

#ifdef __cplusplus
extern "C"
{
#endif

	int Test_3x3mulM(void);

#ifdef __cplusplus
}
#endif

#endif
